package android.aidl.nexos;

import android.aidl.nexos.uce.IUCEService;
import android.aidl.nexos.ft.IFileTransferService;
import android.aidl.nexos.chat.IChatService;
import android.aidl.nexos.chat.IGroupChatService;
import android.aidl.nexos.chat.ILocationService;
import android.aidl.nexos.chat.IMessageStoreService;
import android.aidl.nexos.provisioning.IProvisioningService;
import android.aidl.nexos.provisioning.IProvisioningListener;
import android.aidl.nexos.client.IClientStateListener;
import android.aidl.nexos.client.IPridResponseListener;
import android.aidl.nexos.session.ISharedSessionService;
import android.aidl.nexos.voicemail.IVoicemailService;
import android.aidl.nexos.telephony.IBroadworksSca;
import android.aidl.nexos.telephony.IBroadworksFeatures;
import android.aidl.nexos.telephony.IBroadworksCallPark;

import nexos.RegInfoContact;


interface INexosClient {

	/**
	 * Gets the current client state to the IMS core.
	 * @return the state of the client
	 */
	int getClientState();

	/**
	 * Gets the feature tag used by Nexos.
	 * @return the feature tag
	 */
	String getConnectionFeatureTag();

	/**
	 * Gets the SIP URI of the local user.
	 *
	 * @return the SIP URI of the local user
	 */
	String getLocalUserUri();
	
	/**
	 * Gets a list of SIP URI of the local user.
	 *
	 * @return the list of SIP URI of the local user
	 */
	String[] getLocalUserUris();
	
	/**
	 * Gets the IP of the local device.
	 * 
	 * @return the local IP address, as used by Nexos
	 */ 
	String getLocalIp();

	boolean isProvisioned();
	
	void provisioning();

	void provisioningWithPhoneNumber(String phoneNumber);

	void reProvisioning();

	String formatUriFromPhoneNumber(String phoneNumber, int uriFormat);

	void acceptEndUserMessage(String msgId, String pin);
	void rejectEndUserMessage(String msgId);
	void responseEndUserConfirmation( String id,  int responseType,  String pin);

	void resumeSignIn(int flags);

	void resumeSigninWithoutWifi(int flags);

	boolean isSignInTimingOut();

	void signIn();

	void signOut();

	IUCEService getUCEService();
	IFileTransferService getFileTransferService();
	IChatService getChatService();
	ILocationService getLocationService();
	IProvisioningService getProvisionService();
	IGroupChatService getGroupChatService();
	IMessageStoreService getMessageStoreService();
	ISharedSessionService getSharedSessionService();
	IVoicemailService getVoicemailService();

	String formatToLocalPhoneNumber(String phoneNumber);

	void expireProvisioningData();
	void clearProvisioningData();
	void resetProvisioningData();
	String getOmaAcsConfig(String name, String defaultValue);
	void refreshRegistration();

	/**
	 * Gets the url and protocol.
	 *
	 * @return
	 */

	String getProvUrl();

	String getProvProtocol();

	void invokeOnWebPageRedirected(String url);

	void disableVoiceCallingTags();

	void resetRegisterTags();

	RegInfoContact[] getRegInfoContact();

	void sendGetPridsRequest();

	void sendEmergencyAddressRequest();

	void removePridRequest(String prid, boolean restartApp);

	void setDeviceName(String deviceName);

	String getDeviceName();

	String getDeviceId();

    void renewSPCToken();

	void clearProvPersonalData(int data);

	void setInputProvisioningAddress(String city, String country, String houseNumber, String road, String state, String zip, String location, boolean force);

	String getConnectedProxy();

    String getNexosClientId();

    String getOwnPrid();

    IBroadworksSca getBroadworksSca();

    IBroadworksFeatures getBroadworksFeatures();

    IBroadworksCallPark getBroadworksCallPark();

    void getVMAAspToken();

    boolean sendCapRequest(String event, String eventId, in Map values);

    void addProvisioningListener(IProvisioningListener listener);

    void removeProvisioningListener(IProvisioningListener listener);

    void addClientStateListener(IClientStateListener listener);

    void removeClientStateListener(IClientStateListener listener);

    void addPridResponseListener(IPridResponseListener listener);

    void removePridResponseListener(IPridResponseListener listener);

    String getNetworkName();
}