
// Include your fully-qualified package statement.
package android.aidl.nexos.mmtel;

import android.aidl.nexos.INexosException;
import nexos.mmtel.CallProperties;
import nexos.telephony.ConferenceParticipant;

// Declare the interface.
interface IMMTelSession {
	
	/**
	 * Returns a constant identifying the session's state
	 * 
	 * @return one of the constants listed above.
	 */
	int getState();

	String getSessionId();

	String getNexosClientId();
	
	/**
	 * Returns true if the session initiator is the remote
	 */
	boolean isIncoming();

	/**
	 * If outgoing session, returns the status code of the INVITE response (200
	 * OK, 4xx). If incoming session, returns -1.
	 */
	int getResponseStatusCode();
	
	/**
	 * If outgoing session, returns the reason of the INVITE response when receiving 403 Forbidden.
	 */
	String getResponseReason();

	int getEndReason();

  	String getSubject();
	
	int getCallHealth();
	long getDuration();	
	
	/**
	 * Returns the URI of the peer, i.e. person you are talking to.
	 * 
	 * @return SIP uri of the remote peer.
	 */
	String getRemoteURI();

    /**
	 * Returns the local URI of the peer, i.e your identity used to talk to the
	 * person
	 * 
	 * @return SIP uri of the local peer.
	 */
	String getLocalURI();

	String getRemoteDisplayName();
	
	/**
	 * Indicates if the speaker phone is used to play audio.
	 * 
	 * @return TRUE if the speaker phone is used
	 */
	boolean isSpeakerOn();

	/**
	 * Activate / Deactivate the speaker phone.
	 * 
	 * @return TRUE to activate speaker
	 */
	void setSpeaker(boolean isEnabled);

	/**
	 * Indicates if video is currently active.
	 * 
	 * @return TRUE if the video is active in addition to audio.
	 */
	boolean isVideoActive();

	/**
	 * Gets the current state of the video. Constants are MEDIA_XXX from
	 * MMtelSessionInvitation
	 */
	int getVideoMediaType();
	
	int getAudioMediaType();

	CallProperties getCallProperties();
	
	/**
	 * Gets the timestamp at which the session became active.
	 */
	long getActiveTimestamp();

	/* -- VIDEO -- */

	/**
	 * Upgrade voice session to Video Share or Video Call.
	 * 
	 * @param hasVideoOut
	 *            TRUE if the offered video is two-way.
	 * @return NULL if everything is OK, value if a NexosException was thrown by service - in which case the value if the message of the exception.
	 */
	INexosException offerVideo(int direction);

	void removeVideo();

	INexosException acceptVideo(int direction, boolean terminateExisting);

	void rejectVideoOffer();
	
	void setMuteEnabled(boolean isEnabled);
	boolean isMuteEnabled();
	
	String getVideoCodec(boolean isOutgoing);
	String getAudioCodec(boolean isOutgoing);
	
	INexosException startDTMF(int dtmf);
	INexosException endDTMF();
	
	int getCallPrivacy();

	boolean isInitiatedAsVideoCall();
	
	boolean hasBeenActive();
	
	String[] getOfferedCodecs(boolean isOutgoing, String type);
	String getDebugStats();

    boolean isConsultantCall();
    boolean isRecipientCall();
    boolean isMergeableCall();
    boolean isPotentialSpam();

    String getRemoteUriHistoryInfo();
    String getRemoteDisplayNameHistoryInfo();
    ConferenceParticipant[] getParticipants();
}