// Include your fully-qualified package statement.
package android.aidl.nexos.telephony;

import android.aidl.nexos.mmtel.IMMTelSession;
import android.aidl.nexos.mmtel.ICallSessionListener;
import android.aidl.nexos.mmtel.IVideoCallSessionListener;
import android.aidl.nexos.telephony.ICallHandoverListener;
import android.aidl.nexos.telephony.ITelephonyServiceListener;
import android.aidl.nexos.telephony.ITelephonyStateListener;
import android.aidl.nexos.telephony.IDialogInfoListener;
import android.aidl.nexos.INexosClient;
import nexos.telephony.DialogInfo;
import nexos.telephony.ConferenceParticipant;
import android.view.Surface;

// Declare the interface.
interface ITelephonyService {

	boolean hasRtt(String sessionId);
	boolean sendRttTyped(String sessionId, String text);
	int getCallState();
	IMMTelSession getForegroundCall();
	IMMTelSession getBackgroundCall();
	IMMTelSession getRingingCall();
	IMMTelSession getSessionWithId(String sessionId);
	String[] getAllIds();
	boolean hasBackgroundCall();
	boolean hasRingingCall();
	boolean hasForegroundCall();
	int getLocalCallCount();
	boolean canMakeCall(String uri);
	boolean canUnholdCall(String sessionId);
	IMMTelSession makeCall(String uri, String localUri, String subject);
	IMMTelSession makeConsultantCall(String uri, String localUri, String sessionIdRecipient);
	void answerAsRegularCall();
	IMMTelSession makeVideoCall(String uri, String localUri, String subject);
	void answerCall(boolean terminateExisting, boolean acceptAsVoiceOnly);
	void answerCallWithVideoMode(boolean terminateExisting, int videoMode);
	void rejectCall();
	void rejectCallWithReason(int rejectCode);
	void hangUpCallWithId(String sessionId);
	boolean holdCallWithId(String sessionId);
	boolean unholdCallWithId(String sessionId);
	boolean holdVideoCallWithId(String sessionId);
	boolean unholdVideoCallWithId(String sessionId);
	boolean isVideoOnHold(String sessionId, boolean remoteMedia);
	boolean isCallOnHold(String sessionId);
	boolean isRemoteCallOnHold(String sessionId);
	void addTelephonyServiceListener(in ITelephonyServiceListener listener);
	void removeTelephonyServiceListener(in ITelephonyServiceListener listener);
	void addTelephonyStateListener(in ITelephonyStateListener listener);
    void removeTelephonyStateListener(in ITelephonyStateListener listener);
    void addDialogInfoListener(in IDialogInfoListener listener);
    void removeDialogInfoListener(in IDialogInfoListener listener);
	int getCallPrivacy();
	void setCallPrivacy(int callPrivacy);
	boolean acceptVideoOffer(String sessionId, int videoDirection);
	boolean removeVideo(String sessionId);
	void cancelOutgoingOffer(String sessionId);
	void rejectVideoOffer(String sessionId);
	void setSpeakerMode(boolean isSpeakerOn);
	boolean canMergeCall(String callIdOne, String callIdTwo);
	IMMTelSession mergeCall(String sessionId1, String sessionId2);
	boolean addToConferenceCall(String mergeSessionId, String uri);
	ConferenceParticipant[] getParticipants(String sessionId);
	boolean dropConfParticipant(String callId, String uri);
	boolean isConferenceCall(String sessionId);
	int getConferenceMaxNbrOfParticipants(String sessionId);
	boolean forwardCall(String sessionId, String forwardTo, boolean isConsultative);
	IMMTelSession pullCall(String sessionId);
	IMMTelSession createConfCall(in String[] uriList, int videoMedia);
	DialogInfo[] getDialogInfos();
	boolean isVoiceToVideoUpgradePossible(String sessionId);
    boolean isCSCallActive();
    boolean isCallInCall();
    boolean isCallIdle();
    boolean isCallRinging();
	void addCallSessionListener(in ICallSessionListener listener);
	void removeCallSessionListener(in ICallSessionListener listener);
	void addVideoCallSessionListener(in IVideoCallSessionListener listener);
    void removeVideoCallSessionListener(in IVideoCallSessionListener listener);
    void addCallHandoverListener(in ICallHandoverListener listener);
    void removeCallHandoverListener(in ICallHandoverListener listener);
    boolean giveCodecOwnershipToStack(int codecType, in String pathToCodec);
    int getCodecSource(int codecType);

    void prepareVideoViews(String sessionId, in Surface cameraSurface, in Surface videoSurface);
    void setDisplaySurface(in Surface surface);
    void setCameraSurface(int cameraId, in Surface surface, in String sessionId);
    void offerVideo(String sessionId);
    void setVideoOrientation(String sessionId, int orientation);

    boolean isInCallHandover();
    boolean isVideoHandover();
    String getUriInHandover();

    int getVideoMediaType(String callId);
    int getAudioMediaType(String callId);

    void stopIncomingCallRingtoneVibration();
}
